glum package
=====================

The two main classes in :mod:`glum` are :class:`~glum.GeneralizedLinearRegressor` and :class:`~glum.GeneralizedLinearRegressorCV`. Most users will use :meth:`fit() <glum.GeneralizedLinearRegressor.fit>` and :meth:`predict() <glum.GeneralizedLinearRegressor.predict>`

.. automodule:: glum
   :members:
   :inherited-members:
   :show-inheritance:
